diff --git a/core/lib/Drupal/Component/Plugin/ContextAwarePluginBase.php b/core/lib/Drupal/Component/Plugin/ContextAwarePluginBase.php
index 5d39934..61c497e 100644
--- a/core/lib/Drupal/Component/Plugin/ContextAwarePluginBase.php
+++ b/core/lib/Drupal/Component/Plugin/ContextAwarePluginBase.php
@@ -54,7 +54,7 @@ public function __construct(array $configuration, $plugin_id, array $plugin_defi
    * Implements \Drupal\Component\Plugin\ContextAwarePluginInterface::getContextDefinitions().
    */
   public function getContextDefinitions() {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     return !empty($definition['context']) ? $definition['context'] : array();
   }
 
@@ -62,7 +62,7 @@ public function getContextDefinitions() {
    * Implements \Drupal\Component\Plugin\ContextAwarePluginInterface::getContextDefinition().
    */
   public function getContextDefinition($name) {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     if (empty($definition['context'][$name])) {
       throw new PluginException("The $name context is not a valid context.");
     }
diff --git a/core/lib/Drupal/Component/Plugin/PluginBase.php b/core/lib/Drupal/Component/Plugin/PluginBase.php
index f2cc78b..eccddc9 100644
--- a/core/lib/Drupal/Component/Plugin/PluginBase.php
+++ b/core/lib/Drupal/Component/Plugin/PluginBase.php
@@ -49,16 +49,16 @@ public function __construct(array $configuration, $plugin_id, array $plugin_defi
   }
 
   /**
-   * Implements Drupal\Component\Plugin\PluginInterface::getPluginId().
+   * {@inheritdoc}
    */
   public function getPluginId() {
     return $this->pluginId;
   }
 
   /**
-   * Implements Drupal\Component\Plugin\PluginInterface::getDefinition().
+   * {@inheritdoc}
    */
-  public function getDefinition() {
+  public function getPluginDefinition() {
     return $this->pluginDefinition;
   }
 
diff --git a/core/lib/Drupal/Component/Plugin/PluginInspectionInterface.php b/core/lib/Drupal/Component/Plugin/PluginInspectionInterface.php
index 9157d7c..42eb4b9 100644
--- a/core/lib/Drupal/Component/Plugin/PluginInspectionInterface.php
+++ b/core/lib/Drupal/Component/Plugin/PluginInspectionInterface.php
@@ -29,5 +29,5 @@ public function getPluginId();
    *   The plugin definition, as returned by the discovery object used by the
    *   plugin manager.
    */
-  public function getDefinition();
+  public function getPluginDefinition();
 }
diff --git a/core/lib/Drupal/Core/Condition/ConditionPluginBase.php b/core/lib/Drupal/Core/Condition/ConditionPluginBase.php
index 2bd7910..cd6648e 100644
--- a/core/lib/Drupal/Core/Condition/ConditionPluginBase.php
+++ b/core/lib/Drupal/Core/Condition/ConditionPluginBase.php
@@ -18,7 +18,7 @@
    * Implements \Drupal\Core\Form\FormInterface::getFormID().
    */
   public function getFormID() {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     return implode('_', array($definition['module'], $definition['id'], 'condition'));
   }
 
diff --git a/core/lib/Drupal/Core/Executable/ExecutablePluginBase.php b/core/lib/Drupal/Core/Executable/ExecutablePluginBase.php
index 426e8b8..f35ea44 100644
--- a/core/lib/Drupal/Core/Executable/ExecutablePluginBase.php
+++ b/core/lib/Drupal/Core/Executable/ExecutablePluginBase.php
@@ -41,7 +41,7 @@ public function setExecutableManager(ExecutableManagerInterface $executableManag
    *   options, keyed by option name.
    */
   public function getConfigDefinitions() {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     if (!empty($definition['configuration'])) {
       return $definition['configuration'];
     }
@@ -58,7 +58,7 @@ public function getConfigDefinitions() {
    *   if the option does not exist.
    */
   public function getConfigDefinition($key) {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     if (!empty($definition['configuration'][$key])) {
       return $definition['configuration'][$key];
     }
diff --git a/core/modules/aggregator/lib/Drupal/aggregator/Plugin/aggregator/processor/DefaultProcessor.php b/core/modules/aggregator/lib/Drupal/aggregator/Plugin/aggregator/processor/DefaultProcessor.php
index 6b160ff..79d9d07 100644
--- a/core/modules/aggregator/lib/Drupal/aggregator/Plugin/aggregator/processor/DefaultProcessor.php
+++ b/core/modules/aggregator/lib/Drupal/aggregator/Plugin/aggregator/processor/DefaultProcessor.php
@@ -33,7 +33,7 @@ class DefaultProcessor extends PluginBase implements ProcessorInterface {
   public function settingsForm(array $form, array &$form_state) {
     $config = config('aggregator.settings');
     $processors = $config->get('processors');
-    $info = $this->getDefinition();
+    $info = $this->getPluginDefinition();
     $items = drupal_map_assoc(array(3, 5, 10, 15, 20, 25), array($this, 'formatItems'));
     $period = drupal_map_assoc(array(3600, 10800, 21600, 32400, 43200, 86400, 172800, 259200, 604800, 1209600, 2419200, 4838400, 9676800), 'format_interval');
     $period[AGGREGATOR_CLEAR_NEVER] = t('Never');
diff --git a/core/modules/aggregator/tests/lib/Drupal/aggregator_test/Plugin/aggregator/processor/TestProcessor.php b/core/modules/aggregator/tests/lib/Drupal/aggregator_test/Plugin/aggregator/processor/TestProcessor.php
index e218b8a..d08a272 100644
--- a/core/modules/aggregator/tests/lib/Drupal/aggregator_test/Plugin/aggregator/processor/TestProcessor.php
+++ b/core/modules/aggregator/tests/lib/Drupal/aggregator_test/Plugin/aggregator/processor/TestProcessor.php
@@ -32,7 +32,7 @@ class TestProcessor extends PluginBase implements ProcessorInterface {
   public function settingsForm(array $form, array &$form_state) {
     $config = config('aggregator.settings');
     $processors = $config->get('processors');
-    $info = $this->getDefinition();
+    $info = $this->getPluginDefinition();
 
     $form['processors'][$info['id']] = array(
       '#type' => 'details',
diff --git a/core/modules/block/lib/Drupal/block/BlockBase.php b/core/modules/block/lib/Drupal/block/BlockBase.php
index 57ff44d..adb80fb 100644
--- a/core/modules/block/lib/Drupal/block/BlockBase.php
+++ b/core/modules/block/lib/Drupal/block/BlockBase.php
@@ -111,7 +111,7 @@ public function access() {
    * @see \Drupal\block\BlockBase::blockForm()
    */
   public function form($form, &$form_state) {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     $form['module'] = array(
       '#type' => 'value',
       '#value' => $definition['module'],
diff --git a/core/modules/block/lib/Drupal/block/BlockListController.php b/core/modules/block/lib/Drupal/block/BlockListController.php
index 5b18b3c..fbfeb0f 100644
--- a/core/modules/block/lib/Drupal/block/BlockListController.php
+++ b/core/modules/block/lib/Drupal/block/BlockListController.php
@@ -136,7 +136,7 @@ public function buildForm(array $form, array &$form_state) {
     $form['#tree'] = TRUE;
 
     foreach ($entities as $entity_id => $entity) {
-      $info = $entity->getPlugin()->getDefinition();
+      $info = $entity->getPlugin()->getPluginDefinition();
       $form['blocks'][$entity_id]['info'] = array(
         '#markup' => check_plain($info['admin_label']),
       );
diff --git a/core/modules/block/lib/Drupal/block/Plugin/PluginUI/BlockPluginUI.php b/core/modules/block/lib/Drupal/block/Plugin/PluginUI/BlockPluginUI.php
index cda4836..de7e079 100644
--- a/core/modules/block/lib/Drupal/block/Plugin/PluginUI/BlockPluginUI.php
+++ b/core/modules/block/lib/Drupal/block/Plugin/PluginUI/BlockPluginUI.php
@@ -45,7 +45,7 @@ class BlockPluginUI extends PluginUIBase {
   public function form($form, &$form_state, $facet = NULL) {
     // @todo Add an inline comment here.
     list($plugin, $theme) = explode(':', $this->getPluginId());
-    $plugin_definition = $this->getDefinition();
+    $plugin_definition = $this->getPluginDefinition();
     // @todo Find out how to let the manager be injected into the class.
     $manager = drupal_container()->get($plugin_definition['manager']);
     $plugins = $manager->getDefinitions();
@@ -141,7 +141,7 @@ public function tableHeader() {
    * Overrides \Drupal\system\Plugin\PluginUIBase::row().
    */
   public function row($display_plugin_id, array $display_plugin_definition) {
-    $plugin_definition = $this->getDefinition();
+    $plugin_definition = $this->getPluginDefinition();
     list($plugin, $theme) = explode(':', $this->getPluginId());
     $row = array();
     $row[] = check_plain($display_plugin_definition['admin_label']);
@@ -180,7 +180,7 @@ public function row($display_plugin_id, array $display_plugin_definition) {
    *   Returns a row array comaptible with theme_links().
    */
   protected function facetLink($facet, $display_plugin_id, array $display_plugin_definition) {
-    $plugin_definition = $this->getDefinition();
+    $plugin_definition = $this->getPluginDefinition();
     return array(
       'title' => $display_plugin_definition[$facet],
       'href' => $plugin_definition['path'] . '/' . $this->getPluginId() . '/' . $facet . ':' . $display_plugin_definition[$facet],
@@ -222,7 +222,7 @@ protected function facetCompare($facet, $display_plugin_definition) {
    *   Returns a simple URL string for use within l().
    */
   protected function allPluginsUrl($display_plugin_id, $display_plugin_definition) {
-    $plugin_definition = $this->getDefinition();
+    $plugin_definition = $this->getPluginDefinition();
     return $plugin_definition['path'] . '/' . $this->getPluginId() . '/add';
   }
 
diff --git a/core/modules/field/lib/Drupal/field/Plugin/PluginSettingsBase.php b/core/modules/field/lib/Drupal/field/Plugin/PluginSettingsBase.php
index be22874..06f72e9 100644
--- a/core/modules/field/lib/Drupal/field/Plugin/PluginSettingsBase.php
+++ b/core/modules/field/lib/Drupal/field/Plugin/PluginSettingsBase.php
@@ -65,7 +65,7 @@ protected function mergeDefaults() {
    * Implements Drupal\field\Plugin\PluginSettingsInterface::getDefaultSettings().
    */
   public function getDefaultSettings() {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     return $definition['settings'];
   }
 
diff --git a/core/modules/field/lib/Drupal/field/Plugin/Type/Widget/WidgetBase.php b/core/modules/field/lib/Drupal/field/Plugin/Type/Widget/WidgetBase.php
index 64c83a2..68aecbb 100644
--- a/core/modules/field/lib/Drupal/field/Plugin/Type/Widget/WidgetBase.php
+++ b/core/modules/field/lib/Drupal/field/Plugin/Type/Widget/WidgetBase.php
@@ -100,7 +100,7 @@ public function form(EntityInterface $entity, $langcode, array $items, array &$f
     // If the widget is handling multiple values (e.g Options), or if we are
     // displaying an individual element, just get a single form element and make
     // it the $delta value.
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     if (isset($get_delta) || $definition['multiple_values']) {
       $delta = isset($get_delta) ? $get_delta : 0;
       $element = array(
@@ -368,7 +368,7 @@ public function flagErrors(EntityInterface $entity, $langcode, array $items, arr
 
       // Only set errors if the element is accessible.
       if (!isset($element['#access']) || $element['#access']) {
-        $definition = $this->getDefinition();
+        $definition = $this->getPluginDefinition();
         $is_multiple = $definition['multiple_values'];
 
         foreach ($field_state['errors'] as $delta => $delta_errors) {
diff --git a/core/modules/field/lib/Drupal/field/Tests/FieldInfoTest.php b/core/modules/field/lib/Drupal/field/Tests/FieldInfoTest.php
index 122d14c..978ca54 100644
--- a/core/modules/field/lib/Drupal/field/Tests/FieldInfoTest.php
+++ b/core/modules/field/lib/Drupal/field/Tests/FieldInfoTest.php
@@ -185,7 +185,7 @@ function testInstancePrepare() {
     // Check that the default widget is used and expected settings are in place.
     $widget = $instance->getWidget();
     $this->assertIdentical($widget->getPluginId(), $field_type['default_widget'], 'Unavailable widget replaced with default widget.');
-    $widget_type = $widget->getDefinition();
+    $widget_type = $widget->getPluginDefinition();
     $this->assertIdentical($widget->getSettings(), $widget_type['settings'] , 'All expected widget settings are present.');
   }
 
diff --git a/core/modules/field_ui/lib/Drupal/field_ui/DisplayOverview.php b/core/modules/field_ui/lib/Drupal/field_ui/DisplayOverview.php
index c1a490d..098924c 100644
--- a/core/modules/field_ui/lib/Drupal/field_ui/DisplayOverview.php
+++ b/core/modules/field_ui/lib/Drupal/field_ui/DisplayOverview.php
@@ -201,7 +201,7 @@ public function buildForm(array $form, array &$form_state, $entity_type = NULL,
         $table[$name]['format']['settings_edit_form'] = array();
 
         if ($formatter) {
-          $formatter_type_info = $formatter->getDefinition();
+          $formatter_type_info = $formatter->getPluginDefinition();
 
           // Generate the settings form and allow other modules to alter it.
           $settings_form = $formatter->settingsForm($form, $form_state);
diff --git a/core/modules/layout/lib/Drupal/layout/Plugin/Layout/StaticLayout.php b/core/modules/layout/lib/Drupal/layout/Plugin/Layout/StaticLayout.php
index f88da2f..56e88fe 100644
--- a/core/modules/layout/lib/Drupal/layout/Plugin/Layout/StaticLayout.php
+++ b/core/modules/layout/lib/Drupal/layout/Plugin/Layout/StaticLayout.php
@@ -35,7 +35,7 @@ public function __construct(array $configuration, $plugin_id, array $plugin_defi
    * Implements Drupal\layout\Plugin\LayoutInterface::getRegions().
    */
   public function getRegions() {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     return $definition['regions'];
   }
 
@@ -43,7 +43,7 @@ public function getRegions() {
    * Returns the list of CSS files associated with this layout.
    */
   public function getStylesheetFiles() {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     return isset($definition['stylesheets']) ? $definition['stylesheets'] : array();
   }
 
@@ -51,7 +51,7 @@ public function getStylesheetFiles() {
    * Returns the list of administrative CSS files associated with this layout.
    */
   public function getAdminStylesheetFiles() {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     // Fall back on regular CSS for the admin page if admin CSS not provided.
     return isset($definition['admin stylesheets']) ? $definition['admin stylesheets'] : $this->getStylesheetFiles();
   }
@@ -60,7 +60,7 @@ public function getAdminStylesheetFiles() {
    * Returns the list of JS files associated with this layout.
    */
   public function getScriptFiles() {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     return isset($definition['scripts']) ? $definition['scripts'] : array();
   }
 
@@ -68,7 +68,7 @@ public function getScriptFiles() {
    * Returns the list of administrative JS files associated with this layout.
    */
   public function getAdminScriptFiles() {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     return isset($definition['admin scripts']) ? $definition['admin scripts'] : $this->getScriptFiles();
   }
 
@@ -76,7 +76,7 @@ public function getAdminScriptFiles() {
    * Implements Drupal\layout\Plugin\LayoutInterface::renderLayout().
    */
   public function renderLayout($admin = FALSE, $regions = array()) {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
 
     // Assemble a render array with the regions and attached CSS/JS.
     $build = array(
diff --git a/core/modules/rest/lib/Drupal/rest/Plugin/ResourceBase.php b/core/modules/rest/lib/Drupal/rest/Plugin/ResourceBase.php
index 94abc31..e851352 100644
--- a/core/modules/rest/lib/Drupal/rest/Plugin/ResourceBase.php
+++ b/core/modules/rest/lib/Drupal/rest/Plugin/ResourceBase.php
@@ -25,7 +25,7 @@
    */
   public function permissions() {
     $permissions = array();
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     foreach ($this->availableMethods() as $method) {
       $lowered_method = strtolower($method);
       $permissions["restful $lowered_method $this->pluginId"] = array(
diff --git a/core/modules/rest/lib/Drupal/rest/Plugin/rest/resource/EntityResource.php b/core/modules/rest/lib/Drupal/rest/Plugin/rest/resource/EntityResource.php
index 77bcc00..f1195de 100644
--- a/core/modules/rest/lib/Drupal/rest/Plugin/rest/resource/EntityResource.php
+++ b/core/modules/rest/lib/Drupal/rest/Plugin/rest/resource/EntityResource.php
@@ -42,7 +42,7 @@ class EntityResource extends ResourceBase {
    * @throws \Symfony\Component\HttpKernel\Exception\HttpException
    */
   public function get($id) {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     $entity = entity_load($definition['entity_type'], $id);
     if ($entity) {
       if (!$entity->access('view')) {
@@ -75,7 +75,7 @@ public function post($id, EntityInterface $entity) {
     if (!$entity->access('create')) {
       throw new AccessDeniedHttpException();
     }
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     // Verify that the deserialized entity is of the type that we expect to
     // prevent security issues.
     if ($entity->entityType() != $definition['entity_type']) {
@@ -121,7 +121,7 @@ public function patch($id, EntityInterface $entity) {
     if (empty($id)) {
       throw new NotFoundHttpException();
     }
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     if ($entity->entityType() != $definition['entity_type']) {
       throw new BadRequestHttpException(t('Invalid entity type'));
     }
@@ -178,7 +178,7 @@ public function patch($id, EntityInterface $entity) {
    * @throws \Symfony\Component\HttpKernel\Exception\HttpException
    */
   public function delete($id) {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     $entity = entity_load($definition['entity_type'], $id);
     if ($entity) {
       if (!$entity->access('delete')) {
diff --git a/core/modules/rest/lib/Drupal/rest/RequestHandler.php b/core/modules/rest/lib/Drupal/rest/RequestHandler.php
index 8a23b50..904e32b 100644
--- a/core/modules/rest/lib/Drupal/rest/RequestHandler.php
+++ b/core/modules/rest/lib/Drupal/rest/RequestHandler.php
@@ -53,7 +53,7 @@ public function handle(Request $request, $id = NULL) {
       $config = $this->container->get('config.factory')->get('rest.settings')->get('resources');
       $enabled_formats = $config[$plugin][$request->getMethod()];
       if (empty($enabled_formats) || isset($enabled_formats[$format])) {
-        $definition = $resource->getDefinition();
+        $definition = $resource->getPluginDefinition();
         $class = $definition['serialization_class'];
         try {
           $unserialized = $serializer->deserialize($received, $class, $format);
diff --git a/core/modules/system/lib/Drupal/system/Plugin/PluginUIBase.php b/core/modules/system/lib/Drupal/system/Plugin/PluginUIBase.php
index dd890fd..077ee5b 100644
--- a/core/modules/system/lib/Drupal/system/Plugin/PluginUIBase.php
+++ b/core/modules/system/lib/Drupal/system/Plugin/PluginUIBase.php
@@ -21,7 +21,7 @@
    * Implements \Drupal\system\Plugin\PluginUIInterface::form().
    */
   public function form($form, &$form_state) {
-    $plugin_definition = $this->getDefinition();
+    $plugin_definition = $this->getPluginDefinition();
     // @todo Find out how to let the manager be injected into the class.
     if (class_exists($plugin_definition['manager'])) {
       $manager = new $plugin_definition['manager']();
@@ -63,7 +63,7 @@ public function formSubmit($form, &$form_state) {
    *   Returns TRUE if plugins of this type can be accessed.
    */
   public function access() {
-    $definition = $this->getDefinition();
+    $definition = $this->getPluginDefinition();
     return call_user_func_array($definition['access_callback'], $definition['access_arguments']);
   }
 
@@ -79,7 +79,7 @@ public function access() {
    *   An array that represents a table row in the final user interface output.
    */
   public function row($display_plugin_id, array $display_plugin_definition) {
-    $plugin_definition = $this->getDefinition();
+    $plugin_definition = $this->getPluginDefinition();
     return array($display_plugin_definition['title'], l($plugin_definition['link_title'], $plugin_definition['config_path'] . '/' . $display_plugin_id));
   }
 
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/ViewAddFormController.php b/core/modules/views_ui/lib/Drupal/views_ui/ViewAddFormController.php
index 40f0086..1a4498f 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/ViewAddFormController.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/ViewAddFormController.php
@@ -145,7 +145,7 @@ protected function actions(array $form, array &$form_state) {
   public function validate(array $form, array &$form_state) {
     $wizard_type = $form_state['values']['show']['wizard_key'];
     $wizard_instance = Views::pluginManager('wizard')->createInstance($wizard_type);
-    $form_state['wizard'] = $wizard_instance->getDefinition();
+    $form_state['wizard'] = $wizard_instance->getPluginDefinition();
     $form_state['wizard_instance'] = $wizard_instance;
     $errors = $form_state['wizard_instance']->validateView($form, $form_state);
 

diff --git a/core/modules/system/lib/Drupal/system/Tests/Plugin/InspectionTest.php b/core/modules/system/lib/Drupal/system/Tests/Plugin/InspectionTest.php
index 5daf1e9..2f8168f 100644
--- a/core/modules/system/lib/Drupal/system/Tests/Plugin/InspectionTest.php
+++ b/core/modules/system/lib/Drupal/system/Tests/Plugin/InspectionTest.php
@@ -21,26 +21,32 @@ public static function getInfo() {
   }
 
   /**
    * Ensure the test plugins correctly implement getPluginId() and getDefinition().
    */
   function testInspection() {
     foreach (array('user_login') as $id) {
       $plugin = $this->testPluginManager->createInstance($id);
+      $expected_definition = $this->testPluginExpectedDefinitions[$id];
       $this->assertIdentical($plugin->getPluginId(), $id);
-      $this->assertIdentical($this->testPluginManager->getDefinition($id), $this->testPluginExpectedDefinitions[$id]);
+      $this->assertIdentical($this->testPluginManager->getDefinition($id), $expected_definition);
+      $this->assertIdentical($plugin->getPluginDefinition(), $expected_definition);
     }
     // Skip the 'menu' derived blocks, because MockMenuBlock does not implement
     // PluginInspectionInterface. The others do by extending PluginBase.
     foreach (array('user_login', 'layout') as $id) {
       $plugin = $this->mockBlockManager->createInstance($id);
+      $expected_definition = $this->mockBlockExpectedDefinitions[$id];
       $this->assertIdentical($plugin->getPluginId(), $id);
-      $this->assertIdentical($this->mockBlockManager->getDefinition($id), $this->mockBlockExpectedDefinitions[$id]);
+      $this->assertIdentical($this->mockBlockManager->getDefinition($id), $expected_definition);
+      $this->assertIdentical($plugin->getPluginDefinition(), $expected_definition);
     }
     // Test a plugin manager that provides defaults.
     foreach (array('test_block1', 'test_block2') as $id) {
       $plugin = $this->defaultsTestPluginManager->createInstance($id);
+      $expected_definition = $this->defaultsTestPluginExpectedDefinitions[$id];
       $this->assertIdentical($plugin->getPluginId(), $id);
-      $this->assertIdentical($this->defaultsTestPluginManager->getDefinition($id), $this->defaultsTestPluginExpectedDefinitions[$id]);
+      $this->assertIdentical($this->defaultsTestPluginManager->getDefinition($id), $expected_definition);
+      $this->assertIdentical($plugin->getPluginDefinition(), $expected_definition);
     }
   }
 
@@ -21,26 +21,32 @@ public static function getInfo() {
 
   /**
-   * Ensure the test plugins correctly implement getPluginId() and getDefinition().
+   * Ensure the test plugins correctly implement getPluginId() and getPluginDefinition().
    */
   function testInspection() {